#include "../fastnetmon_types.hpp"
#include <string>

void exabgp_ban_manage(std::string action, std::string ip_as_string, attack_details_t current_attack);
